{{/*
Common labels
*/}}
{{- define "activemq.labels" -}}
{{ include "activemq-utils.labels" . }}
{{- end -}}

{{/*
Selector labels
*/}}
{{- define "activemq.selectorLabels" -}}
{{ include "activemq-utils.selectorLabels" . }}
{{- end -}}

{{/*
    ActiveMQ Broker Name
*/}}
{{- define "_activemq.requiredBrokerName" -}}
{{- required "You must specify the 'brokerName' to be created" .Values.brokerName -}}
{{- end -}}

{{- define "_activemq.fullBrokerName" -}}
{{ include "activemq-utils.externalNamingPrefix" . }}-{{ include "_activemq.requiredBrokerName" .}}
{{- end -}}

{{- define "activemq.brokerName" -}}
{{- $brokerName:= ( include "_activemq.fullBrokerName" . ) -}}
{{- if not (mustRegexMatch "^[a-zA-Z0-9_.-]+$" .Values.brokerName) -}}
{{- fail "'brokerName' failed to satisfy constraint: Member must satisfy regular expression pattern: [a-zA-Z0-9_.-]+" -}}
{{- end -}}
{{- $lenBrokerName := $brokerName | len | float64 -}}
{{- if ge $lenBrokerName .Values.maxNameLength -}}
{{- printf "\nThe generated brokerName %s is greater than the allowed number of characters %f." $brokerName .Values.maxNameLength | fail -}}
{{- else -}}
{{- printf "%s" $brokerName -}}
{{- end -}}
{{- end -}}

{{/*
  The user password secret name
*/}}
{{- define "activemq.brokerUserPassCredentialsSecretName" -}}
  {{ include "activemq-utils.namingPrefix" . }}-pass
{{- end -}}

{{/*
  The user username secret name
*/}}
{{- define "activemq.brokerUserUsernameCredentialsSecretName" -}}
  {{ include "activemq-utils.namingPrefix" . }}-user
{{- end -}}

{{/*
  The kubernetes service name for the broker endpoint
*/}}
{{- define "activemq.brokerEndpoint" -}}
  {{ include "activemq.brokerEndpointShortName" . }}.{{ include "activemq-utils.infraNamespace" . }}.svc.cluster.local
{{- end -}}

{{/*
  The kubernetes sort service name for the broker endpoint
*/}}
{{- define "activemq.brokerEndpointShortName" -}}
  {{ include "activemq-utils.namingPrefix" . }}-endpoint
{{- end -}}

{{/*
  Check versions for matching the public Dockerhub images see: https://hub.docker.com/r/symptoma/activemq/tags

  This isn't updated frequently, so there will be drift between the local patch and the one running in AWS.
*/}}
{{- define "activemq.getLocalVersion" -}}
{{- $image := "symptoma/activemq" -}}
{{- if (default nil .Values.localVersion) -}}
{{- printf "%s:%s" $image .Values.localVersion -}}
{{- else -}}
{{- if semverCompare "~5.15" .Values.engineVersion -}}
{{- printf "%s:%s" $image "5.15.13" -}}
{{- else if semverCompare "~5.16" .Values.engineVersion -}}
{{- printf "%s:%s" $image "5.16.4" -}}
{{- else if semverCompare "~5.17" .Values.engineVersion -}}
{{- printf "%s:%s" $image "5.17.4" -}}
{{- else if semverCompare "~5.18" .Values.engineVersion -}}
{{- printf "%s:%s" $image "5.18.2" -}}
{{- else -}}
{{- printf "%s:%s" $image "latest" -}}
{{- end -}}
{{- end -}}
{{- end -}}